@@ -11,7 +11,6 @@ fi
 #-------print error only-------
 cd "${__DIR__}" && cd ../ && \
 ./clear.sh > /dev/null && \
-./make.sh clean > /dev/null && \
 phpize --clean > /dev/null && \
 phpize > /dev/null && \
 ./configure \
@@ -19,8 +18,7 @@ phpize > /dev/null && \
 --enable-http2 \
 --enable-sockets \
 --enable-mysqlnd \
---enable-swoole-json \
---enable-swoole-curl \
+--enable-hook-curl \
 --enable-cares \
 --with-postgres \
 > /dev/null && \
